dev-pipeline-core
=================
|codacy|
|code-climate|

Common functionality required for most `dev-pipeline`_ plugins.


Installation
------------
The simplest way to install is using pip_.

.. code:: bash

    $ cd /path/to/dev-pipeline-core
    $ pip3 install

If you don't have pip available, you can run :code:`setup.py` directly.

.. code:: bash

    $ cd /path/to/dev-pipeline-core
    $ python3 setup.py install


.. |codacy| image:: https://api.codacy.com/project/badge/Grade/39922e6d959249de8b6a7d3ce891b318
    :target: https://www.codacy.com/app/snewell/devpipeline-core?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=dev-pipeline/devpipeline-core&amp;utm_campaign=Badge_Grade

.. |code-climate| image:: https://api.codeclimate.com/v1/badges/2fbefb414100af5742a6/maintainability
   :target: https://codeclimate.com/github/dev-pipeline/devpipeline-core/maintainability
   :alt: Maintainability

.. _dev-pipeline: https://github.com/dev-pipeline/dev-pipeline
.. _pip: https://pypi.python.org/pypi/pip
